==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/AppearanceSourceType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p135820_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:p874817_="https://jakarta.ee/xml/ns/jaxb" xmlns:p942898_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Used to set the data source for the visible appearance of an annotation.&#13;
 * &#13;
 *                 &lt;/p&gt;
 * </pre>
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p135820_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:p874817_="https://jakarta.ee/xml/ns/jaxb" xmlns:p942898_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&lt;b&gt;Important:&lt;/b&gt;&#13;
 *                     If this element is present, this shall always take precedence for the appearance generation.&#13;
 *                 &lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for AppearanceSourceType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="AppearanceSourceType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <choice>
 *         <element name="pdf" type="{http://schema.webpdf.de/1.0/operation}AppearancePdfType"/>
 *         <element name="image" type="{http://schema.webpdf.de/1.0/operation}AppearanceImageType"/>
 *         <element name="svg" type="{http://schema.webpdf.de/1.0/operation}AppearanceSvgType"/>
 *       </choice>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AppearanceSourceType", propOrder = {
    "pdf",
    "image",
    "svg"
})
public class AppearanceSourceType {

    protected AppearancePdfType pdf;
    protected AppearanceImageType image;
    protected AppearanceSvgType svg;

    /**
     * Gets the value of the pdf property.
     * 
     * @return
     *     possible object is
     *     {@link AppearancePdfType }
     *     
     */
    public AppearancePdfType getPdf() {
        return pdf;
    }

    /**
     * Sets the value of the pdf property.
     * 
     * @param value
     *     allowed object is
     *     {@link AppearancePdfType }
     *     
     */
    public void setPdf(AppearancePdfType value) {
        this.pdf = value;
    }

    public boolean isSetPdf() {
        return (this.pdf!= null);
    }

    /**
     * Gets the value of the image property.
     * 
     * @return
     *     possible object is
     *     {@link AppearanceImageType }
     *     
     */
    public AppearanceImageType getImage() {
        return image;
    }

    /**
     * Sets the value of the image property.
     * 
     * @param value
     *     allowed object is
     *     {@link AppearanceImageType }
     *     
     */
    public void setImage(AppearanceImageType value) {
        this.image = value;
    }

    public boolean isSetImage() {
        return (this.image!= null);
    }

    /**
     * Gets the value of the svg property.
     * 
     * @return
     *     possible object is
     *     {@link AppearanceSvgType }
     *     
     */
    public AppearanceSvgType getSvg() {
        return svg;
    }

    /**
     * Sets the value of the svg property.
     * 
     * @param value
     *     allowed object is
     *     {@link AppearanceSvgType }
     *     
     */
    public void setSvg(AppearanceSvgType value) {
        this.svg = value;
    }

    public boolean isSetSvg() {
        return (this.svg!= null);
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/AppearanceSourceType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p105796_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p913707_="https://jakarta.ee/xml/ns/jaxb" xmlns:p931759_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Used to set the data source for the visible appearance of an annotation.&#13;
 * &#13;
 *                 &lt;/p&gt;
 * </pre>
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p105796_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p913707_="https://jakarta.ee/xml/ns/jaxb" xmlns:p931759_="http://jaxb2-commons.dev.java.net/basic/simplify" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&lt;b&gt;Important:&lt;/b&gt;&#13;
 *                     If this element is present, this shall always take precedence for the appearance generation.&#13;
 *                 &lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for AppearanceSourceType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="AppearanceSourceType">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <choice>
 *         <element name="pdf" type="{http://schema.webpdf.de/1.0/operation}AppearancePdfType"/>
 *         <element name="image" type="{http://schema.webpdf.de/1.0/operation}AppearanceImageType"/>
 *         <element name="svg" type="{http://schema.webpdf.de/1.0/operation}AppearanceSvgType"/>
 *       </choice>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AppearanceSourceType", propOrder = {
    "pdf",
    "image",
    "svg"
})
public class AppearanceSourceType {

    protected AppearancePdfType pdf;
    protected AppearanceImageType image;
    protected AppearanceSvgType svg;

    /**
     * Gets the value of the pdf property.
     * 
     * @return
     *     possible object is
     *     {@link AppearancePdfType }
     *     
     */
    public AppearancePdfType getPdf() {
        return pdf;
    }

    /**
     * Sets the value of the pdf property.
     * 
     * @param value
     *     allowed object is
     *     {@link AppearancePdfType }
     *     
     */
    public void setPdf(AppearancePdfType value) {
        this.pdf = value;
    }

    public boolean isSetPdf() {
        return (this.pdf!= null);
    }

    /**
     * Gets the value of the image property.
     * 
     * @return
     *     possible object is
     *     {@link AppearanceImageType }
     *     
     */
    public AppearanceImageType getImage() {
        return image;
    }

    /**
     * Sets the value of the image property.
     * 
     * @param value
     *     allowed object is
     *     {@link AppearanceImageType }
     *     
     */
    public void setImage(AppearanceImageType value) {
        this.image = value;
    }

    public boolean isSetImage() {
        return (this.image!= null);
    }

    /**
     * Gets the value of the svg property.
     * 
     * @return
     *     possible object is
     *     {@link AppearanceSvgType }
     *     
     */
    public AppearanceSvgType getSvg() {
        return svg;
    }

    /**
     * Sets the value of the svg property.
     * 
     * @param value
     *     allowed object is
     *     {@link AppearanceSvgType }
     *     
     */
    public void setSvg(AppearanceSvgType value) {
        this.svg = value;
    }

    public boolean isSetSvg() {
        return (this.svg!= null);
    }

}
